# encoding: utf-8

module FFaker
  module CoursesFR
    module Mathematiques
      extend ModuleUtils
      extend self
      def lesson
        fetch_sample(LESSONS)
      end
    end

    module Philosophie
      extend ModuleUtils
      extend self
      def lesson
        fetch_sample(LESSONS)
      end
    end
  end
end
